module.exports = {"version":"v1","baseUrl":"https://firebasedynamiclinks-ipv6.googleapis.com/","kind":"discovery#restDescription","description":"Programmatically creates and manages Firebase Dynamic Links.","servicePath":"","basePath":"","revision":"20171031","documentationLink":"https://firebase.google.com/docs/dynamic-links/","id":"firebasedynamiclinks:v1","discoveryVersion":"v1","version_module":true,"schemas":{"AndroidInfo":{"type":"object","properties":{"androidPackageName":{"description":"Android package name of the app.","type":"string"},"androidMinPackageVersionCode":{"description":"Minimum version code for the Android app. If the installed app’s version\ncode is lower, then the user is taken to the Play Store.","type":"string"},"androidLink":{"description":"If specified, this overrides the ‘link’ parameter on Android.","type":"string"},"androidFallbackLink":{"description":"Link to open on Android if the app is not installed.","type":"string"}},"id":"AndroidInfo","description":"Android related attributes to the Dynamic Link."},"DynamicLinkWarning":{"type":"object","properties":{"warningMessage":{"description":"The warning message to help developers improve their requests.","type":"string"},"warningDocumentLink":{"description":"The document describing the warning, and helps resolve.","type":"string"},"warningCode":{"enum":["CODE_UNSPECIFIED","NOT_IN_PROJECT_ANDROID_PACKAGE_NAME","NOT_INTEGER_ANDROID_PACKAGE_MIN_VERSION","UNNECESSARY_ANDROID_PACKAGE_MIN_VERSION","NOT_URI_ANDROID_LINK","UNNECESSARY_ANDROID_LINK","NOT_URI_ANDROID_FALLBACK_LINK","BAD_URI_SCHEME_ANDROID_FALLBACK_LINK","NOT_IN_PROJECT_IOS_BUNDLE_ID","NOT_IN_PROJECT_IPAD_BUNDLE_ID","UNNECESSARY_IOS_URL_SCHEME","NOT_NUMERIC_IOS_APP_STORE_ID","UNNECESSARY_IOS_APP_STORE_ID","NOT_URI_IOS_FALLBACK_LINK","BAD_URI_SCHEME_IOS_FALLBACK_LINK","NOT_URI_IPAD_FALLBACK_LINK","BAD_URI_SCHEME_IPAD_FALLBACK_LINK","BAD_DEBUG_PARAM","BAD_AD_PARAM","DEPRECATED_PARAM","UNRECOGNIZED_PARAM","TOO_LONG_PARAM","NOT_URI_SOCIAL_IMAGE_LINK","BAD_URI_SCHEME_SOCIAL_IMAGE_LINK","NOT_URI_SOCIAL_URL","BAD_URI_SCHEME_SOCIAL_URL","LINK_LENGTH_TOO_LONG","LINK_WITH_FRAGMENTS","NOT_MATCHING_IOS_BUNDLE_ID_AND_STORE_ID"],"description":"The warning code.","type":"string","enumDescriptions":["Unknown code.","The Android package does not match any in developer's DevConsole project.","The Android minimum version code has to be a valid integer.","Android package min version param is not needed, e.g. when\n'apn' is missing.","Android link is not a valid URI.","Android link param is not needed, e.g. when param 'al' and 'link' have\nthe same value..","Android fallback link is not a valid URI.","Android fallback link has an invalid (non http/https) URI scheme.","The iOS bundle ID does not match any in developer's DevConsole project.","The iPad bundle ID does not match any in developer's DevConsole project.","iOS URL scheme is not needed, e.g. when 'ibi' are 'ipbi' are all missing.","iOS app store ID format is incorrect, e.g. not numeric.","iOS app store ID is not needed.","iOS fallback link is not a valid URI.","iOS fallback link has an invalid (non http/https) URI scheme.","iPad fallback link is not a valid URI.","iPad fallback link has an invalid (non http/https) URI scheme.","Debug param format is incorrect.","isAd param format is incorrect.","Indicates a certain param is deprecated.","Indicates certain paramater is not recognized.","Indicates certain paramater is too long.","Social meta tag image link is not a valid URI.","Social meta tag image link has an invalid (non http/https) URI scheme.","","","Dynamic Link URL length is too long.","Dynamic Link URL contains fragments.","The iOS bundle ID does not match with the given iOS store ID."]}},"id":"DynamicLinkWarning","description":"Dynamic Links warning messages."},"DynamicLinkStats":{"properties":{"linkEventStats":{"description":"Dynamic Link event stats.","type":"array","items":{"$ref":"DynamicLinkEventStat"}}},"id":"DynamicLinkStats","description":"Analytics stats of a Dynamic Link for a given timeframe.","type":"object"},"NavigationInfo":{"properties":{"enableForcedRedirect":{"description":"If this option is on, FDL click will be forced to redirect rather than\nshow an interstitial page.","type":"boolean"}},"id":"NavigationInfo","description":"Information of navigation behavior.","type":"object"},"IosInfo":{"id":"IosInfo","description":"iOS related attributes to the Dynamic Link..","type":"object","properties":{"iosIpadBundleId":{"type":"string","description":"iPad bundle ID of the app."},"iosCustomScheme":{"description":"Custom (destination) scheme to use for iOS. By default, we’ll use the\nbundle ID as the custom scheme. Developer can override this behavior using\nthis param.","type":"string"},"iosBundleId":{"description":"iOS bundle ID of the app.","type":"string"},"iosFallbackLink":{"description":"Link to open on iOS if the app is not installed.","type":"string"},"iosAppStoreId":{"description":"iOS App Store ID.","type":"string"},"iosIpadFallbackLink":{"description":"If specified, this overrides the ios_fallback_link value on iPads.","type":"string"}}},"AnalyticsInfo":{"type":"object","properties":{"googlePlayAnalytics":{"description":"Google Play Campaign Measurements.","$ref":"GooglePlayAnalytics"},"itunesConnectAnalytics":{"$ref":"ITunesConnectAnalytics","description":"iTunes Connect App Analytics."}},"id":"AnalyticsInfo","description":"Tracking parameters supported by Dynamic Link."},"CreateShortDynamicLinkRequest":{"id":"CreateShortDynamicLinkRequest","description":"Request to create a short Dynamic Link.","type":"object","properties":{"longDynamicLink":{"description":"Full long Dynamic Link URL with desired query parameters specified.\nFor example,\n\"https://sample.app.goo.gl/?link=http://www.google.com&apn=com.sample\",\n[Learn more](https://firebase.google.com/docs/dynamic-links/android#create-a-dynamic-link-programmatically).","type":"string"},"suffix":{"$ref":"Suffix","description":"Short Dynamic Link suffix. Optional."},"dynamicLinkInfo":{"$ref":"DynamicLinkInfo","description":"Information about the Dynamic Link to be shortened.\n[Learn more](https://firebase.google.com/docs/dynamic-links/android#create-a-dynamic-link-programmatically)."}}},"DesktopInfo":{"properties":{"desktopFallbackLink":{"description":"Link to open on desktop.","type":"string"}},"id":"DesktopInfo","description":"Desktop related attributes to the Dynamic Link.","type":"object"},"DynamicLinkEventStat":{"id":"DynamicLinkEventStat","description":"Dynamic Link event stat.","type":"object","properties":{"count":{"description":"The number of times this event occurred.","format":"int64","type":"string"},"event":{"enumDescriptions":["Unspecified type.","Indicates that an FDL is clicked by users.","Indicates that an FDL redirects users to fallback link.","Indicates that an FDL triggers an app install from Play store, currently\nit's impossible to get stats from App store.","Indicates that the app is opened for the first time after an install\ntriggered by FDLs","Indicates that the app is opened via an FDL for non-first time."],"enum":["DYNAMIC_LINK_EVENT_UNSPECIFIED","CLICK","REDIRECT","APP_INSTALL","APP_FIRST_OPEN","APP_RE_OPEN"],"description":"Link event.","type":"string"},"platform":{"enum":["DYNAMIC_LINK_PLATFORM_UNSPECIFIED","ANDROID","IOS","DESKTOP"],"description":"Requested platform.","type":"string","enumDescriptions":["Unspecified platform.","Represents Android platform.\nAll apps and browsers on Android are classfied in this category.","Represents iOS platform.\nAll apps and browsers on iOS are classfied in this category.","Represents desktop.\nNote: other platforms like Windows, Blackberry, Amazon fall into this\ncategory."]}}},"GetIosPostInstallAttributionRequest":{"type":"object","properties":{"visualStyle":{"description":"Strong match page information. Disambiguates between default UI and\ncustom page to present when strong match succeeds/fails to find cookie.","type":"string","enumDescriptions":["Unknown style.","Default style.","Custom style."],"enum":["UNKNOWN_VISUAL_STYLE","DEFAULT_STYLE","CUSTOM_STYLE"]},"retrievalMethod":{"enum":["UNKNOWN_PAYLOAD_RETRIEVAL_METHOD","IMPLICIT_WEAK_MATCH","EXPLICIT_WEAK_MATCH","EXPLICIT_STRONG_AFTER_WEAK_MATCH"],"description":"App post install attribution retrieval information. Disambiguates\nmechanism (iSDK or developer invoked) to retrieve payload from\nclicked link.","type":"string","enumDescriptions":["Unknown method.","iSDK performs a server lookup by device fingerprint in the background\nwhen app is first-opened; no API called by developer.","iSDK performs a server lookup by device fingerprint upon a dev API call.","iSDK performs a strong match only if weak match is found upon a dev\nAPI call."]},"sdkVersion":{"type":"string","description":"Google SDK version."},"bundleId":{"type":"string","description":"APP bundle ID."},"device":{"$ref":"DeviceInfo","description":"Device information."},"uniqueMatchLinkToCheck":{"description":"Possible unique matched link that server need to check before performing\nfingerprint match. If passed link is short server need to expand the link.\nIf link is long server need to vslidate the link.","type":"string"},"appInstallationTime":{"description":"App installation epoch time (https://en.wikipedia.org/wiki/Unix_time).\nThis is a client signal for a more accurate weak match.","format":"int64","type":"string"},"iosVersion":{"description":"iOS version, ie: 9.3.5.\nConsider adding \"build\".","type":"string"}},"id":"GetIosPostInstallAttributionRequest","description":"Request for iSDK to execute strong match flow for post-install attribution.\nThis is meant for iOS requests only. Requests from other platforms will\nnot be honored."},"CreateShortDynamicLinkResponse":{"description":"Response to create a short Dynamic Link.","type":"object","properties":{"shortLink":{"description":"Short Dynamic Link value. e.g. https://abcd.app.goo.gl/wxyz","type":"string"},"previewLink":{"description":"Preivew link to show the link flow chart.","type":"string"},"warning":{"description":"Information about potential warnings on link creation.","type":"array","items":{"$ref":"DynamicLinkWarning"}}},"id":"CreateShortDynamicLinkResponse"},"Suffix":{"description":"Short Dynamic Link suffix.","type":"object","properties":{"option":{"enumDescriptions":["The suffix option is not specified, performs as NOT_GUESSABLE .","Short Dynamic Link suffix is a base62 [0-9A-Za-z] encoded string of\na random generated 96 bit random number, which has a length of 17 chars.\nFor example, \"nlAR8U4SlKRZw1cb2\".\nIt prevents other people from guessing and crawling short Dynamic Links\nthat contain personal identifiable information.","Short Dynamic Link suffix is a base62 [0-9A-Za-z] string starting with a\nlength of 4 chars. the length will increase when all the space is\noccupied."],"enum":["OPTION_UNSPECIFIED","UNGUESSABLE","SHORT"],"description":"Suffix option.","type":"string"}},"id":"Suffix"},"GooglePlayAnalytics":{"description":"Parameters for Google Play Campaign Measurements.\n[Learn more](https://developers.google.com/analytics/devguides/collection/android/v4/campaigns#campaign-params)","type":"object","properties":{"utmContent":{"description":"Campaign content; used for A/B testing and content-targeted ads to\ndifferentiate ads or links that point to the same URL.","type":"string"},"utmMedium":{"description":"Campaign medium; used to identify a medium such as email or cost-per-click.","type":"string"},"utmTerm":{"description":"Campaign term; used with paid search to supply the keywords for ads.","type":"string"},"utmSource":{"type":"string","description":"Campaign source; used to identify a search engine, newsletter, or other\nsource."},"gclid":{"description":"[AdWords autotagging parameter](https://support.google.com/analytics/answer/1033981?hl=en);\nused to measure Google AdWords ads. This value is generated dynamically\nand should never be modified.","type":"string"},"utmCampaign":{"type":"string","description":"Campaign name; used for keyword analysis to identify a specific product\npromotion or strategic campaign."}},"id":"GooglePlayAnalytics"},"DynamicLinkInfo":{"type":"object","properties":{"analyticsInfo":{"$ref":"AnalyticsInfo","description":"Parameters used for tracking. See all tracking parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"dynamicLinkDomain":{"description":"Dynamic Links domain that the project owns, e.g. abcd.app.goo.gl\n[Learn more](https://firebase.google.com/docs/dynamic-links/android/receive)\non how to set up Dynamic Link domain associated with your Firebase project.\n\nRequired.","type":"string"},"desktopInfo":{"$ref":"DesktopInfo","description":"Desktop related information. See desktop related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"link":{"description":"The link your app will open, You can specify any URL your app can handle.\nThis link must be a well-formatted URL, be properly URL-encoded, and use\nthe HTTP or HTTPS scheme. See 'link' parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually).\n\nRequired.","type":"string"},"iosInfo":{"$ref":"IosInfo","description":"iOS related information. See iOS related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"socialMetaTagInfo":{"description":"Parameters for social meta tag params.\nUsed to set meta tag data for link previews on social sites.","$ref":"SocialMetaTagInfo"},"androidInfo":{"$ref":"AndroidInfo","description":"Android related information. See Android related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"navigationInfo":{"$ref":"NavigationInfo","description":"Information of navigation behavior of a Firebase Dynamic Links."}},"id":"DynamicLinkInfo","description":"Information about a Dynamic Link."},"ITunesConnectAnalytics":{"description":"Parameters for iTunes Connect App Analytics.","type":"object","properties":{"at":{"description":"Affiliate token used to create affiliate-coded links.","type":"string"},"ct":{"description":"Campaign text that developers can optionally add to any link in order to\ntrack sales from a specific marketing campaign.","type":"string"},"mt":{"description":"iTune media types, including music, podcasts, audiobooks and so on.","type":"string"},"pt":{"description":"Provider token that enables analytics for Dynamic Links from within iTunes\nConnect.","type":"string"}},"id":"ITunesConnectAnalytics"},"DeviceInfo":{"description":"Signals associated with the device making the request.","type":"object","properties":{"screenResolutionWidth":{"description":"Device display resolution width.","format":"int64","type":"string"},"deviceModelName":{"type":"string","description":"Device model name."},"screenResolutionHeight":{"description":"Device display resolution height.","format":"int64","type":"string"},"languageCode":{"description":"Device language code setting.","type":"string"},"timezone":{"description":"Device timezone setting.","type":"string"}},"id":"DeviceInfo"},"GetIosPostInstallAttributionResponse":{"description":"Response for iSDK to execute strong match flow for post-install attribution.","type":"object","properties":{"fallbackLink":{"description":"The link to navigate to update the app if min version is not met.\nThis is either (in order): 1) fallback link (from ?ifl= parameter, if\nspecified by developer) or 2) AppStore URL (from ?isi= parameter, if\nspecified), or 3) the payload link (from required link= parameter).","type":"string"},"requestedLink":{"description":"Entire FDL (short or long) attributed post-install via one of several\ntechniques (fingerprint, copy unique).","type":"string"},"utmMedium":{"description":"Scion medium value to be propagated by iSDK to Scion at post-install.","type":"string"},"utmSource":{"description":"Scion source value to be propagated by iSDK to Scion at post-install.","type":"string"},"isStrongMatchExecutable":{"description":"Instruction for iSDK to attemmpt to perform strong match. For instance,\nif browser does not support/allow cookie or outside of support browsers,\nthis will be false.","type":"boolean"},"appMinimumVersion":{"description":"The minimum version for app, specified by dev through ?imv= parameter.\nReturn to iSDK to allow app to evaluate if current version meets this.","type":"string"},"invitationId":{"type":"string","description":"Invitation ID attributed post-install via one of several techniques\n(fingerprint, copy unique)."},"deepLink":{"description":"The deep-link attributed post-install via one of several techniques\n(fingerprint, copy unique).","type":"string"},"externalBrowserDestinationLink":{"description":"User-agent specific custom-scheme URIs for iSDK to open. This will be set\naccording to the user-agent tha the click was originally made in. There is\nno Safari-equivalent custom-scheme open URLs.\nie: googlechrome://www.example.com\nie: firefox://open-url?url=http://www.example.com\nie: opera-http://example.com","type":"string"},"attributionConfidence":{"description":"The confidence of the returned attribution.","type":"string","enumDescriptions":["Unset.","Weak confidence, more than one matching link found or link suspected to\nbe false positive","Default confidence, match based on fingerprint","Unique confidence, match based on \"unique match link to check\" or other\nmeans"],"enum":["UNKNOWN_ATTRIBUTION_CONFIDENCE","WEAK","DEFAULT","UNIQUE"]},"matchMessage":{"description":"Describes why match failed, ie: \"discarded due to low confidence\".\nThis message will be publicly visible.","type":"string"},"resolvedLink":{"description":"The entire FDL, expanded from a short link. It is the same as the\nrequested_link, if it is long. Parameters from this should not be\nused directly (ie: server can default utm_[campaign|medium|source]\nto a value when requested_link lack them, server determine the best\nfallback_link when requested_link specifies >1 fallback links).","type":"string"},"utmCampaign":{"description":"Scion campaign value to be propagated by iSDK to Scion at post-install.","type":"string"}},"id":"GetIosPostInstallAttributionResponse"},"SocialMetaTagInfo":{"description":"Parameters for social meta tag params.\nUsed to set meta tag data for link previews on social sites.","type":"object","properties":{"socialDescription":{"description":"A short description of the link. Optional.","type":"string"},"socialTitle":{"description":"Title to be displayed. Optional.","type":"string"},"socialImageLink":{"description":"An image url string. Optional.","type":"string"}},"id":"SocialMetaTagInfo"}},"icons":{"x32":"http://www.google.com/images/icons/product/search-32.gif","x16":"http://www.google.com/images/icons/product/search-16.gif"},"protocol":"rest","canonicalName":"Firebase Dynamic Links","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/firebase":{"description":"View and administer all your Firebase data and settings"}}}},"rootUrl":"https://firebasedynamiclinks-ipv6.googleapis.com/","ownerDomain":"google.com","name":"firebasedynamiclinks","batchPath":"batch","title":"Firebase Dynamic Links API","ownerName":"Google","resources":{"shortLinks":{"methods":{"create":{"request":{"$ref":"CreateShortDynamicLinkRequest"},"description":"Creates a short Dynamic Link given either a valid long Dynamic Link or\ndetails such as Dynamic Link domain, Android and iOS app information.\nThe created short Dynamic Link will not expire.\n\nRepeated calls with the same long Dynamic Link or Dynamic Link information\nwill produce the same short Dynamic Link.\n\nThe Dynamic Link domain in the request must be owned by requester's\nFirebase project.","httpMethod":"POST","parameterOrder":[],"response":{"$ref":"CreateShortDynamicLinkResponse"},"parameters":{},"scopes":["https://www.googleapis.com/auth/firebase"],"flatPath":"v1/shortLinks","id":"firebasedynamiclinks.shortLinks.create","path":"v1/shortLinks"}}},"v1":{"methods":{"getLinkStats":{"response":{"$ref":"DynamicLinkStats"},"parameterOrder":["dynamicLink"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/firebase"],"parameters":{"durationDays":{"description":"The span of time requested in days.","format":"int64","type":"string","location":"query"},"dynamicLink":{"description":"Dynamic Link URL. e.g. https://abcd.app.goo.gl/wxyz","required":true,"type":"string","location":"path"}},"flatPath":"v1/{dynamicLink}/linkStats","path":"v1/{dynamicLink}/linkStats","id":"firebasedynamiclinks.getLinkStats","description":"Fetches analytics stats of a short Dynamic Link for a given\nduration. Metrics include number of clicks, redirects, installs,\napp first opens, and app reopens."},"installAttribution":{"request":{"$ref":"GetIosPostInstallAttributionRequest"},"description":"Get iOS strong/weak-match info for post-install attribution.","httpMethod":"POST","parameterOrder":[],"response":{"$ref":"GetIosPostInstallAttributionResponse"},"parameters":{},"scopes":["https://www.googleapis.com/auth/firebase"],"flatPath":"v1/installAttribution","id":"firebasedynamiclinks.installAttribution","path":"v1/installAttribution"}}}},"parameters":{"$.xgafv":{"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"]},"callback":{"location":"query","description":"JSONP","type":"string"},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"access_token":{"description":"OAuth access token.","type":"string","location":"query"},"key":{"type":"string","location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token."},"quotaUser":{"type":"string","location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters."},"pp":{"description":"Pretty-print response.","type":"boolean","default":"true","location":"query"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"bearer_token":{"description":"OAuth bearer token.","type":"string","location":"query"},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"}}};